@@ -8,7 +8,7 @@ from timestream.dimensions import TimestreamDimensions
 from timestream.load_result import TimestreamLoadResult
 from timestream.record import RejectedTimestreamRecord, TimestreamRecord
 from timestream.timestream_reader import TimestreamReader
-from timestream.multi_measure import TimestreamRecordMulti
+from timestream.multi_measure import TimestreamRecordMulti, RejectedTimestreamRecordMulti
 from timestream.util import is_time_key, is_version_key
 from typing import List
 
@@ -233,7 +233,7 @@ class TimestreamLoader(TimestreamReader):
             accepted_records, rejected_records = self.__process_client_error(e, records)
         return accepted_records, rejected_records
 
-    def __process_client_error(self, e: ClientError, records: List[TimestreamRecord]) -> tuple:
+    def __process_client_error(self, e: ClientError, records: List[dict], is_multi: bool = False) -> tuple:
         '''
         Processes a boto ClientError from a Timestream write operation. Logs error messages
         for each rejected Timestream record and returns 2 lists:
@@ -242,10 +242,17 @@ class TimestreamLoader(TimestreamReader):
         '''
         rejected_records, rejected_indices = [], []
         for rejection_data in e.response.get('RejectedRecords', []):
-            rejected_record = RejectedTimestreamRecord(
-                record=records[rejection_data['RecordIndex']],
-                error=Exception(rejection_data['Reason'])
-            )
+            if is_multi:
+                rejected_record = RejectedTimestreamRecordMulti(
+                    record=records[rejection_data['RecordIndex']],
+                    error=Exception(rejection_data['Reason'])
+                )
+            
+            else:
+                rejected_record = RejectedTimestreamRecord(
+                    record=records[rejection_data['RecordIndex']],
+                    error=Exception(rejection_data['Reason'])
+                )
             self._logger.error(f'Rejected record:\n{rejected_record}')
             rejected_records.append(rejected_record)
             rejected_indices.append(rejection_data['RecordIndex'])
